summaryrefslogtreecommitdiff
path: root/src/ypipe.hpp
diff options
context:
space:
mode:
authorMartin Sustrik <sustrik@fastmq.commkdir>2009-08-03 11:30:13 +0200
committerMartin Sustrik <sustrik@fastmq.commkdir>2009-08-03 11:30:13 +0200
commitcc3755a16f00026af882ed14d122cc8aa6d50e82 (patch)
tree33a2197bab1bd6068dbfcc446fe70aaa07808fa9 /src/ypipe.hpp
parent183b6887644ac05c951a3f9143248ed86e91052f (diff)
renamed from zs to zmq
Diffstat (limited to 'src/ypipe.hpp')
-rw-r--r--src/ypipe.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/ypipe.hpp b/src/ypipe.hpp
index 5ffd5c9..01b4137 100644
--- a/src/ypipe.hpp
+++ b/src/ypipe.hpp
@@ -17,14 +17,14 @@
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef __ZS_YPIPE_HPP_INCLUDED__
-#define __ZS_YPIPE_HPP_INCLUDED__
+#ifndef __ZMQ_YPIPE_HPP_INCLUDED__
+#define __ZMQ_YPIPE_HPP_INCLUDED__
#include "atomic_ptr.hpp"
#include "yqueue.hpp"
#include "platform.hpp"
-namespace zs
+namespace zmq
{
// Lock-free queue implementation.
@@ -58,7 +58,7 @@ namespace zs
}
// Following function (write) deliberately copies uninitialised data
// when used with zs_msg. Initialising the VSM body for
// non-VSM messages won't be good for performance.
#ifdef ZMQ_HAVE_OPENVMS
@@ -58,7 +58,7 @@ namespace zs
}
// Following function (write) deliberately copies uninitialised data
- // when used with zs_msg. Initialising the VSM body for
+ // when used with zmq_msg. Initialising the VSM body for
// non-VSM messages won't be good for performance.
#ifdef ZMQ_HAVE_OPENVMS